@@ -49,6 +49,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def AddNodeResourceConfig(self, request):
+        """增加当前集群的节点规格配置
+
+        :param request: Request instance for AddNodeResourceConfig.
+        :type request: :class:`tencentcloud.emr.v20190103.models.AddNodeResourceConfigRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.AddNodeResourceConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddNodeResourceConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddNodeResourceConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AddUsersForUserManager(self, request):
         """该接口支持安装了OpenLdap组件的集群。
         新增用户列表（用户管理）。
@@ -73,6 +96,52 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def AttachDisks(self, request):
+        """云盘挂载
+
+        :param request: Request instance for AttachDisks.
+        :type request: :class:`tencentcloud.emr.v20190103.models.AttachDisksRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.AttachDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AttachDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.AttachDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateCloudInstance(self, request):
+        """创建EMR容器集群实例
+
+        :param request: Request instance for CreateCloudInstance.
+        :type request: :class:`tencentcloud.emr.v20190103.models.CreateCloudInstanceRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.CreateCloudInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCloudInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCloudInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateCluster(self, request):
         """创建EMR集群实例
 
@@ -120,9 +189,9 @@ class EmrClient(AbstractClient):
 
 
     def CreateSLInstance(self, request):
-        """本接口（CreateSLInstance）用于创建 Lite HBase 实例
-        - 接口调用成功，会创建Lite HBase实例，创建实例请求成功会返回创建实例的 InstaceId 和请求的 RequestID。
-        - 接口为异步接口，接口返回时操作并未立即完成，实例操作结果可以通过调用 DescribeInstancesList 查看当前实例的 StatusDesc 状态。
+        """本接口（CreateSLInstance）用于创建Serverless HBase实例
+        - 接口调用成功，会创建Serverless HBase实例，创建实例请求成功会返回创建实例的InstaceId和请求的 RequestID。
+        - 接口为异步接口，接口返回时操作并未立即完成，实例操作结果可以通过调用DescribeInstancesList查看当前实例的StatusDesc状态。
 
         :param request: Request instance for CreateSLInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.CreateSLInstanceRequest`
@@ -167,6 +236,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteNodeResourceConfig(self, request):
+        """删除当前集群的节点规格配置
+
+        :param request: Request instance for DeleteNodeResourceConfig.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DeleteNodeResourceConfigRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DeleteNodeResourceConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteNodeResourceConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteNodeResourceConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteUserManagerUserList(self, request):
         """删除用户列表（用户管理）
 
@@ -351,6 +443,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDAGInfo(self, request):
+        """查询DAG信息
+
+        :param request: Request instance for DescribeDAGInfo.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeDAGInfoRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeDAGInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDAGInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDAGInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeEmrApplicationStatics(self, request):
         """yarn application 统计接口查询
 
@@ -650,6 +765,52 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeNodeDataDisks(self, request):
+        """查询节点数据盘信息
+
+        :param request: Request instance for DescribeNodeDataDisks.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeNodeDataDisksRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeNodeDataDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNodeDataDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNodeDataDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeNodeResourceConfigFast(self, request):
+        """快速获取当前集群的节点规格配置
+
+        :param request: Request instance for DescribeNodeResourceConfigFast.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeNodeResourceConfigFastRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeNodeResourceConfigFastResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNodeResourceConfigFast", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNodeResourceConfigFastResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeResourceSchedule(self, request):
         """查询YARN资源调度数据信息。已废弃，请使用`DescribeYarnQueue`去查询队列信息。
 
@@ -697,7 +858,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeSLInstance(self, request):
-        """本接口（DescribeSLInstance）用于查询 Lite HBase 实例基本信息
+        """本接口（DescribeSLInstance）用于查询 Serverless HBase实例基本信息
 
         :param request: Request instance for DescribeSLInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeSLInstanceRequest`
@@ -720,7 +881,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeSLInstanceList(self, request):
-        """本接口（DescribeSLInstanceList）用于查询 Lite HBase 实例列表详细信息
+        """本接口（DescribeSLInstanceList）用于查询Serverless HBase实例列表详细信息
 
         :param request: Request instance for DescribeSLInstanceList.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeSLInstanceListRequest`
@@ -812,7 +973,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeTrinoQueryInfo(self, request):
-        """获取trino查询结果
+        """查询Trino(PrestoSQL)查询信息
 
         :param request: Request instance for DescribeTrinoQueryInfo.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeTrinoQueryInfoRequest`
@@ -1112,6 +1273,75 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceBasic(self, request):
+        """修改集群名称
+
+        :param request: Request instance for ModifyInstanceBasic.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyInstanceBasicRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyInstanceBasicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceBasic", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceBasicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyPodNum(self, request):
+        """调整Pod数量
+
+        :param request: Request instance for ModifyPodNum.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyPodNumRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyPodNumResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyPodNum", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyPodNumResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyResource(self, request):
+        """变配实例
+
+        :param request: Request instance for ModifyResource.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResource", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyResourceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyResourcePools(self, request):
         """刷新YARN的动态资源池。已废弃，请使用`DeployYarnConf`
 
@@ -1205,9 +1435,9 @@ class EmrClient(AbstractClient):
 
 
     def ModifySLInstance(self, request):
-        """本接口（ModifySLInstance）用于修改Lite HBase 实例节点数。
-        - 接口调用成功，会创建Lite HBase实例，创建实例请求成功会返回请求的 RequestID。
-        - 接口为异步接口，接口返回时操作并未立即完成，实例操作结果可以通过调用 DescribeInstancesList 查看当前实例的 StatusDesc 状态。
+        """本接口（ModifySLInstance）用于Serverless HBase变配实例。
+        - 接口调用成功，会创建Serverless HBase实例，创建实例请求成功会返回请求的 RequestID。
+        - 接口为异步接口，接口返回时操作并未立即完成，实例操作结果可以通过调用DescribeInstancesList查看当前实例的StatusDesc状态。
 
         :param request: Request instance for ModifySLInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.ModifySLInstanceRequest`
@@ -1321,6 +1551,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ResizeDataDisks(self, request):
+        """云盘扩容
+
+        :param request: Request instance for ResizeDataDisks.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ResizeDataDisksRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ResizeDataDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ResizeDataDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.ResizeDataDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RunJobFlow(self, request):
         """创建流程作业
 
@@ -1390,6 +1643,29 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SetNodeResourceConfigDefault(self, request):
+        """设置当前集群的某个节点规格配置为默认或取消默认
+
+        :param request: Request instance for SetNodeResourceConfigDefault.
+        :type request: :class:`tencentcloud.emr.v20190103.models.SetNodeResourceConfigDefaultRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.SetNodeResourceConfigDefaultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SetNodeResourceConfigDefault", params, headers=headers)
+            response = json.loads(body)
+            model = models.SetNodeResourceConfigDefaultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StartStopServiceOrMonitor(self, request):
         """用于启停服务 重启服务等功能
 
@@ -1483,7 +1759,7 @@ class EmrClient(AbstractClient):
 
 
     def TerminateSLInstance(self, request):
-        """本接口（TerminateSLInstance）用于销毁 Lite HBase 实例
+        """本接口（TerminateSLInstance）用于销毁Serverless HBase实例
 
         :param request: Request instance for TerminateSLInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.TerminateSLInstanceRequest`
